import React, { useState, useEffect } from 'react';
import {
  scaleTime,
  extent,
  scaleLinear,
  max,
  min,
  line,
} from 'd3';
import { YmarkerLine } from './YmarkerLine';
import { XmarkerLine } from './XmarkerLine';
import { XAxis } from './XAxis';

const xValue = (d) => d.date;
const yValue = (d) => d.deathTotal;

const margin = { left: 90, right: 80, top: 40, bottom: 40 };
export const LineChart = ({ data, width, height }) => {
  const innerWidth = width - (margin.left + margin.right);
  const innerHeight = height - (margin.top + margin.bottom);

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0]);

  const lineGenerator = line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)));

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <YmarkerLine
          innerWidth={innerWidth}
          yScale={yScale}
          value={1000000}
        />
        <XmarkerLine
          innerHeight={innerHeight}
          xScale={xScale}
          value={xScale.domain()[1]}
        />
                <XAxis
          xScale={xScale}
                   innerHeight={innerHeight}
        />
        <path d={lineGenerator(data)} />
      </g>
    </svg>
  );
};
